@@ -13,7 +13,6 @@
 #include <KIO/Global>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KMessageBox_KTCompat>
 #include <KStandardGuiItem>
 
 #include "settings.h"
@@ -70,7 +69,7 @@ FileSelectDlg::FileSelectDlg(kt::QueueManager *qman, kt::GroupManager *gman, con
     m_move_when_completed_history->setPopupMode(QToolButton::MenuButtonPopup);
 
     encodings = QTextCodec::availableMibs();
-    for (int mib : qAsConst(encodings)) {
+    for (int mib : std::as_const(encodings)) {
         m_encoding->addItem(QString::fromUtf8(QTextCodec::codecForMib(mib)->name()));
     }
 
@@ -560,7 +559,7 @@ void FileSelectDlg::onCodecChanged(const int index)
 
 void FileSelectDlg::loadState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("FileSelectDlg");
+    KConfigGroup g = cfg->group(QStringLiteral("FileSelectDlg"));
     QSize s = g.readEntry("size", sizeHint());
     resize(s);
     show_file_tree = g.readEntry("show_file_tree", true);
@@ -593,7 +592,7 @@ void FileSelectDlg::loadState(KSharedConfigPtr cfg)
 
 void FileSelectDlg::saveState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("FileSelectDlg");
+    KConfigGroup g = cfg->group(QStringLiteral("FileSelectDlg"));
     g.writeEntry("size", size());
     g.writeEntry("show_file_tree", show_file_tree);
     g.writeEntry("download_location_history", download_location_history);
