@@ -64,7 +64,7 @@ void TorrentFileTreeModel::Node::insert(const QString &path, bt::TorrentFileInte
         children.append(new Node(this, file, path, num_chunks));
     } else {
         QString subdir = path.left(p);
-        for (Node *n : qAsConst(children)) {
+        for (Node *n : std::as_const(children)) {
             if (n->name == subdir) {
                 n->insert(path.mid(p + 1), file, num_chunks);
                 return;
@@ -92,7 +92,7 @@ bt::Uint64 TorrentFileTreeModel::Node::fileSize(const bt::TorrentInterface *tc)
 
     if (!file) {
         // directory
-        for (Node *n : qAsConst(children))
+        for (Node *n : std::as_const(children))
             size += n->fileSize(tc);
     } else {
         size = file->getSize();
@@ -106,7 +106,7 @@ void TorrentFileTreeModel::Node::fillChunks()
         return;
 
     if (!file) {
-        for (Node *n : qAsConst(children)) {
+        for (Node *n : std::as_const(children)) {
             n->fillChunks();
             chunks.orBitSet(n->chunks);
         }
@@ -169,7 +169,7 @@ void TorrentFileTreeModel::Node::initPercentage(const bt::TorrentInterface *tc,
             percentage = 100.0f * ((float)tmp.numOnBits() / (float)chunks.numOnBits());
         }
 
-        for (Node *n : qAsConst(children))
+        for (Node *n : std::as_const(children))
             n->initPercentage(tc, havechunks); // update the percentage of the children
     }
 }
@@ -180,7 +180,7 @@ bt::Uint64 TorrentFileTreeModel::Node::bytesToDownload(const bt::TorrentInterfac
 
     if (!file) {
         // directory
-        for (Node *n : qAsConst(children))
+        for (Node *n : std::as_const(children))
             s += n->bytesToDownload(tc);
     } else {
         if (!file->doNotDownload())
@@ -195,7 +195,7 @@ Qt::CheckState TorrentFileTreeModel::Node::checkState(const bt::TorrentInterface
         bool found_checked = false;
         bool found_unchecked = false;
         // directory
-        for (Node *n : qAsConst(children)) {
+        for (Node *n : std::as_const(children)) {
             Qt::CheckState s = n->checkState(tc);
             if (s == Qt::PartiallyChecked)
                 return s;
@@ -214,7 +214,11 @@ Qt::CheckState TorrentFileTreeModel::Node::checkState(const bt::TorrentInterface
     }
 }
 
-void TorrentFileTreeModel::Node::saveExpandedState(const QModelIndex &index, QSortFilterProxyModel *pm, QTreeView *tv, BEncoder *enc)
+void TorrentFileTreeModel::Node::saveExpandedState(const QModelIndex &index,
+                                                   TorrentFileTreeModel *real_model,
+                                                   QSortFilterProxyModel *pm,
+                                                   QTreeView *tv,
+                                                   BEncoder *enc) const
 {
     if (file)
         return;
@@ -223,18 +227,22 @@ void TorrentFileTreeModel::Node::saveExpandedState(const QModelIndex &index, QSo
     enc->write((Uint32)(tv->isExpanded(pm->mapFromSource(index)) ? 1 : 0));
 
     int idx = 0;
-    for (Node *n : qAsConst(children)) {
+    for (Node *n : std::as_const(children)) {
         if (!n->file) {
             enc->write(n->name.toUtf8());
             enc->beginDict();
-            n->saveExpandedState(pm->index(idx, 0, index), pm, tv, enc);
+            n->saveExpandedState(real_model->index(idx, 0, index), real_model, pm, tv, enc);
             enc->end();
         }
         idx++;
     }
 }
 
-void TorrentFileTreeModel::Node::loadExpandedState(const QModelIndex &index, QSortFilterProxyModel *pm, QTreeView *tv, BNode *n)
+void TorrentFileTreeModel::Node::loadExpandedState(const QModelIndex &index,
+                                                   TorrentFileTreeModel *real_model,
+                                                   QSortFilterProxyModel *pm,
+                                                   QTreeView *tv,
+                                                   BNode *n) const
 {
     if (file)
         return;
@@ -248,10 +256,10 @@ void TorrentFileTreeModel::Node::loadExpandedState(const QModelIndex &index, QSo
         tv->setExpanded(pm->mapFromSource(index), v->data().toInt() == 1);
 
     int idx = 0;
-    for (Node *n : qAsConst(children)) {
+    for (Node *n : std::as_const(children)) {
         if (!n->file) {
             if (BDictNode *d = dict->getDict(n->name.toUtf8()))
-                n->loadExpandedState(pm->index(idx, 0, index), pm, tv, d);
+                n->loadExpandedState(real_model->index(idx, 0, index), real_model, pm, tv, d);
         }
         idx++;
     }
@@ -536,7 +544,7 @@ bool TorrentFileTreeModel::setName(const QModelIndex &index, const QString &name
             tc->setUserModifiedFileName(name);
         } else {
             // Check if there is a sibling with the same name
-            for (const Node *sibling : qAsConst(n->parent->children)) {
+            for (const Node *sibling : std::as_const(n->parent->children)) {
                 if (sibling != n && sibling->name == name)
                     return false;
             }
@@ -549,7 +557,7 @@ bool TorrentFileTreeModel::setName(const QModelIndex &index, const QString &name
         return true;
     } else {
         // Check if there is a sibling with the same name
-        for (const Node *sibling : qAsConst(n->parent->children)) {
+        for (const Node *sibling : std::as_const(n->parent->children)) {
             if (sibling != n && sibling->name == name)
                 return false;
         }
@@ -635,7 +643,7 @@ QByteArray TorrentFileTreeModel::saveExpandedState(QSortFilterProxyModel *pm, QT
     QByteArray data;
     BEncoder enc(new BEncoderBufferOutput(data));
     enc.beginDict();
-    root->saveExpandedState(index(0, 0, QModelIndex()), pm, tv, &enc);
+    root->saveExpandedState(index(0, 0, QModelIndex()), this, pm, tv, &enc);
     enc.end();
     return data;
 }
@@ -650,7 +658,7 @@ void TorrentFileTreeModel::loadExpandedState(QSortFilterProxyModel *pm, QTreeVie
     try {
         n = dec.decode();
         if (n && n->getType() == BNode::DICT) {
-            root->loadExpandedState(index(0, 0, QModelIndex()), pm, tv, n);
+            root->loadExpandedState(index(0, 0, QModelIndex()), this, pm, tv, n);
         }
     } catch (bt::Error &err) {
         Out(SYS_GEN | LOG_DEBUG) << "Failed to load expanded state" << endl;
