@@ -324,7 +324,9 @@ void IWFileTreeModel::update()
         }
 
         if (changed)
-            dataChanged(createIndex(0, 2), createIndex(0, 4));
+            Q_EMIT dataChanged(createIndex(0, 2), createIndex(0, 4));
     }
 }
 }
+
+#include "moc_iwfiletreemodel.cpp"
