@@ -48,11 +48,9 @@ PeerViewModel::Item::Item(bt::PeerInterface *peer
     }
 
 #if BUILD_WITH_GEOIP
-    int country_id = geo_ip->findCountry(stats.ip_address);
-    if (country_id > 0) {
-        country = geo_ip->countryName(country_id);
-        flag = flagDB.getFlag(geo_ip->countryCode(country_id));
-    }
+    const Country c = geo_ip->findCountry(stats.ip_address);
+    country = c.name;
+    flag = flagDB.getFlag(c.code);
 #endif
 }
 
@@ -217,7 +215,7 @@ void PeerViewModel::peerRemoved(bt::PeerInterface *peer)
 {
     int row = 0;
     bool found = false;
-    for (Item *i : qAsConst(items)) {
+    for (Item *i : std::as_const(items)) {
         if (i->peer == peer) {
             found = true;
             break;
@@ -244,7 +242,7 @@ void PeerViewModel::update()
     int lowest = -1;
     int highest = -1;
 
-    for (Item *i : qAsConst(items)) {
+    for (Item *i : std::as_const(items)) {
         if (i->changed()) {
             if (lowest == -1)
                 lowest = idx;
